@@ -71,7 +71,7 @@ class MappingClass(click.ParamType):
         return entity_mapping
 
 
-@click.group(name="nlu")
+@click.group(name="nlu", short_help='For short text classification and entity extraction')
 def nlu():
     pass
 
@@ -96,28 +96,34 @@ def nlu_get_languages(log_level: Text):
     "--from-platform",
     type=click.Choice(["dialogflow", "rasa", "csv", "luis"], case_sensitive=False),
     required=True,
-    help="From where to convert data from [dialogflow, rasa, csv, luis]",
+    help="Where to convert data from [dialogflow, rasa, csv, luis]",
 )
 @click.option(
     "-at",
     "--auto-tag-entities",
     is_flag=True,
     default=False,
-    help="You can use auto-tag entities to tag the entities with our pre-trained entities",
+    help="If the names of your entities are the same as our pretrained entities "
+         "then tag them automatically as pre-trained",
 )
 @click.option(
     "-L",
     "--language",
     type=click.STRING,
     required=True,
-    help="List of languages. -L en -L de; You can add multiple languages",
+    help="Language in which the dataset is. "
+         "Use the following to get a list of supported languages: neuralspace nlu get-languages",
 )
 @click.option(
     "-em",
     "--entity-mapping",
     type=MappingClass(),
     required=False,
-    help="You can give entities mapping like 'your_entity_name:ns_entity_name,...",
+    help="If your entity names don't match with our pre-trained entity names then you can give a mapping like this:"
+         "'your_entity_name:ns_entity_name,...' and we will convert them to our format. "
+         "This argument works best with the --auto-tag-entities argument as it can happen in a "
+         "lot of cases that your entity names don't match our pre-trained entity names, "
+         "or even regex and lookup entities. This helps you make make the best out of the platform.",
 )
 @click.option(
     "-t",
@@ -131,7 +137,7 @@ def nlu_get_languages(log_level: Text):
     "--input-path",
     required=True,
     multiple=True,
-    help="Name of the folder in which the dataset files are in",
+    help="Name of the folder in which the dataset files are",
 )
 @click.option(
     "-o",
